/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.util;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * Indicates that <code>Qualifier</code> annotation member
 * is not contained in the type safe resolution algorithm.
 * 
 * <p>
 * Example:
 * 
 * <pre>
 * &#064;Qualifier
 * public @interface Mock {
 *   &#064;NonBinding String name;
 * }
 * </pre>
 * 
 * <b>Mock</b> qualifier <i>name</i> member variable is excepted from the
 * type safe resolution algorithm while comparing the qualifiers.
 * 
 * </p>
 */
@Retention(RUNTIME)
@Target(METHOD)
public @interface Nonbinding
{
    final class Literal extends AnnotationLiteral<Nonbinding> implements Nonbinding
    {
        public static final Literal INSTANCE = new Literal();

        private static final long serialVersionUID = 1L;
    }
}
